==> img0ch-3.1.7.tar.bz2: img0ch/_template/zeromin2/bbs_select_threads_to_move.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu_bbs.cs" ?>

<?cs include:"zeromin2/thread_right_menu.cs" ?>

<div id="main">

<form id="threadsContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_index&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">インデックス</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;sort_by=<?cs var:html_escape(SortBy) ?>&amp;descend=<?cs var:html_escape(Descend) ?>" onclick="Zeromin2.redirect(this);return false">スレッド整理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=select_threads_to_move&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">移転するスレッドの選択</a>
</div>

<h1>移転するスレッドの選択</h1>

<?cs if:Code0 ?>
<?cs if:Done_bbs_move_thread ?><div class="noticeSuccess" id="notify"><p>スレッドを移転先の掲示板に移動させました</p></div><?cs /if ?>
<?cs if:Done_bbs_load_threads ?><div class="" id="notify"></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs if:Code2 ?><div class="noticeFailed" id="notify"><p>操作対象のスレッドが選択されていません</p></div><?cs /if ?>
<?cs if:Code3 ?><div class="noticeFailed" id="notify"><p>移転先の掲示板が選択されていません</p></div><?cs /if ?>
<?cs if:Code4 ?><div class="noticeFailed" id="notify"><p>移転元の掲示板と移転先が同一です</p></div><?cs /if ?>
<?cs /if ?>

<p>
現在掲示板(<strong><?cs var:html_escape(BBSName) ?></strong>)に存在するスレッドを移転します。
</p>
<p>
<ul>
<li>「スレッド」はShiftキーを押しながら選択すると複数選択することが可能です</li>
<li>移転先の掲示板にスレッドがコピーされます。元のスレッドは残りますが、内容は書き換えられます。</li>
<li>アップロードされたファイルのディレクトリは移転先の掲示板からシンボリックリンクが作成されます。</li>
<li>移転先の掲示板に同じスレッドキーが存在する場合、スレッドの移転は失敗します。</li>
</ul>
</p>

<p>
選択されたスレッドを指定された掲示板に<input type="submit" value="移転" /><br />
<input type="checkbox" name="delete" value="1" />&nbsp;元のスレッドを削除する
</p>

<div>
<p style="float:left;width:300px;height:375px">
移転元のスレッド(複数可)<br />
<select name="thread" size="25" multiple="multiple" style="width:280px">
  <?cs each:item = Threads ?><option value="<?cs var:html_escape(item.key) ?>"><?cs var:html_escape(item.key) ?> (<?cs var:html_escape(item.subject) ?>)</option>
<?cs /each ?>
</select>
</p>

<p style="float:left;width:300px;height:375px">
移転先となる掲示板(ひとつのみ)<br />
<select name="to" size="25" style="width:280px">
  <?cs each:item = BBSList ?><option value="<?cs var:html_escape(item.dir) ?>"><?cs var:html_escape(item.dir) ?> (<?cs var:html_escape(item.name) ?>)</option>
<?cs /each ?>
</select>
</p>
</div>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="bbs" />
<input type="hidden" name="method" value="move_thread" />
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
<input type="hidden" name="OK" value="select_threads_to_move" />
<input type="hidden" name="NG" value="select_threads_to_move" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>

==> img0ch-3.1.9.tar.bz2: img0ch/_template/zeromin2/bbs_select_threads_to_move.cs <==
<?cs include:"zeromin2/header.cs" ?>

<?cs include:"zeromin2/menu_bbs.cs" ?>

<?cs include:"zeromin2/thread_right_menu.cs" ?>

<div id="main">

<form id="threadsContainerForm" action="<?cs var:html_escape(ZerominScript) ?>" method="post">

<div id="navhead">
  <hr />
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">掲示板管理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_index&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">インデックス</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;sort_by=<?cs var:html_escape(SortBy) ?>&amp;descend=<?cs var:html_escape(Descend) ?>" onclick="Zeromin2.redirect(this);return false">スレッド整理</a>
  &gt;
  <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=select_threads_to_move&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">移転するスレッドの選択</a>
</div>

<h1>移転するスレッドの選択</h1>

<?cs if:Code0 ?>
<?cs if:Done_bbs_move_thread ?><div class="noticeSuccess" id="notify"><p>スレッドを移転先の掲示板に移動させました</p></div><?cs /if ?>
<?cs if:Done_bbs_load_threads ?><div class="" id="notify"></div><?cs /if ?>
<?cs else ?>
<?cs if:Code1 ?><div class="noticeFailed" id="notify"><p>実行権限がありません</p></div><?cs /if ?>
<?cs if:Code2 ?><div class="noticeFailed" id="notify"><p>操作対象のスレッドが選択されていません</p></div><?cs /if ?>
<?cs if:Code3 ?><div class="noticeFailed" id="notify"><p>移転先の掲示板が選択されていません</p></div><?cs /if ?>
<?cs if:Code4 ?><div class="noticeFailed" id="notify"><p>移転元の掲示板と移転先が同一です</p></div><?cs /if ?>
<?cs /if ?>

<p>
現在掲示板(<strong><?cs var:html_escape(BBSName) ?></strong>)に存在するスレッドを移転します。
</p>
<p>
<ul>
<li>「スレッド」はShiftキーを押しながら選択すると複数選択することが可能です</li>
<li>移転先の掲示板にスレッドがコピーされます。元のスレッドは残りますが、内容は書き換えられます。</li>
<li>アップロードされたファイルのディレクトリは移転先の掲示板からシンボリックリンクが作成されます。</li>
<li>移転先の掲示板に同じスレッドキーが存在する場合、スレッドの移転は失敗します。</li>
</ul>
</p>

<p>
選択されたスレッドを指定された掲示板に<input type="submit" value="移転" /><br />
<input type="checkbox" name="delete" value="1" />&nbsp;元のスレッドを削除する
</p>

<div>
<p style="float:left;width:300px;height:375px">
移転元のスレッド(複数可)<br />
<select name="thread" size="25" multiple="multiple" style="width:280px">
  <?cs each:item = Threads ?><option value="<?cs var:html_escape(item.key) ?>"><?cs var:html_escape(item.key) ?> (<?cs var:item.subject ?>)</option>
<?cs /each ?>
</select>
</p>

<p style="float:left;width:300px;height:375px">
移転先となる掲示板(ひとつのみ)<br />
<select name="to" size="25" style="width:280px">
  <?cs each:item = BBSList ?><option value="<?cs var:html_escape(item.dir) ?>"><?cs var:html_escape(item.dir) ?> (<?cs var:html_escape(item.name) ?>)</option>
<?cs /each ?>
</select>
</p>
</div>

<div class="formFooter">
<input type="hidden" name="<?cs var:html_escape(SessionName) ?>" value="<?cs var:html_escape(Session) ?>" />
<input type="hidden" name="token" value="<?cs var:html_escape(Token) ?>" />
<input type="hidden" name="class" value="bbs" />
<input type="hidden" name="method" value="move_thread" />
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
<input type="hidden" name="OK" value="select_threads_to_move" />
<input type="hidden" name="NG" value="select_threads_to_move" />
<br id="endmain" />
</div>

</form>

</div>

<?cs include:"zeromin2/footer.cs" ?>
